@@ -1,9 +1,15 @@
-from .simulationwithredux2 import Simulator
-from .simulationwithredux2 import simpleODESolver
-from .simulationwithredux2 import createDataSelector
+from .simulation import Simulator
+from .simulation import simpleODESolver
+from .simulation import createDataSelector
 
 import scipy.integrate as integrate
 
+__all__ = [
+    'Simulator',
+    'simpleODESolver',
+    'createDataSelector'
+    ]
+
 def CreateDataSelector(masterMaps, maps):
     def extractor(dataItem):
         result = {}
